# -*- coding: UTF-8 -*-
#
# Скачивание файла по ссылке полученной из сообщения
#

from artix.common import py2to3utils
from plugins import downloadfile
from plugins import status
from plugins import writetofile
import logger
import os
import tempfile

log = logger.getLogger()
messageLocalPathKey = 'localPath'
tmpPath = os.path.normpath('%s/file.tmp' % tempfile.gettempdir())


def getLocalPath(message):
    # Получаем локальный путь
    log.info('Получаем локальный путь, по которому будет сохранен скачанный файл')
    path = str(message.properties.get(messageLocalPathKey))
    if path == '' or path is None:
        log.warning('Не указан путь, по которому необходимо сохранить скачанный файл. Файл сохранится во временную директорию %s' % path)
        path = tmpPath
    log.info('Путь для сохранения файла: %s' % path)
    path = os.path.normpath(path)
    if not os.path.exists(os.path.dirname(path)):
        os.makedirs(os.path.dirname(path))
    vers = ''
    num = 1
    while os.path.exists(path + vers):
        vers = '_' + str(num)
        num += 1
    path = path + vers
    return path


def main(message):
    fileLocation = message.properties.get('fileLocation')

    log.info('Получаем тело сообщения')
    body = message.content

    localPath = getLocalPath(message)
    fileName = os.path.basename(localPath)
    fileDir = os.path.dirname(localPath)

    if fileLocation == 'url':
        url = py2to3utils.ensureStr(body)
        if url:
            res, mess = downloadfile.main(url, fileDir, fileName)
            return (status.OK if res else status.errorDownload), mess
        mess = 'Ссылка на скачиваемый файл не указана'
        log.warning(mess)
        return status.errorDownload, mess
    elif fileLocation == 'body':
        if body:
            writetofile.main(body, fileDir, fileName)
            return status.OK, 'Файл скачан'
        mess = 'Нет файла в теле сообщения'
        log.warning(mess)
        return status.errorDownload, mess
    mess = 'Не указано расположение файла. Свойство fileLocation должно иметь значение url или body'
    log.error(mess)
    return status.errorDownload, mess
